@@ -30,7 +30,11 @@ namespace Gnome
 namespace Vfs
 {
 
-void handle_result(GnomeVFSResult result) throw(Gnome::Vfs::exception);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  void handle_result(GnomeVFSResult result) throw(Gnome::Vfs::exception);
+#else
+  void handle_result(GnomeVFSResult result, std::auto_ptr<Gnome::Vfs::exception>& error);
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 } // namespace Vfs
 } // namespace Gnome
